==> vue-month-table-3.23.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentiny/vue-renderless/month-table/vue';
import { defineComponent, $prefix, setup } from '@opentiny/vue-common';
import { isDate1 } from '@opentiny/utils';
import { openBlock, createElementBlock, createElementVNode, Fragment, renderList, normalizeClass, toDisplayString } from 'vue';
import '@opentiny/vue-theme/month-table/index.css';

function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function() {
      return o >= r.length ? { done: true } : { done: false, value: r[o++] };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}
function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
var _export_sfc = function _export_sfc2(sfc, props) {
  var target = sfc.__vccOpts || sfc;
  for (var _iterator = _createForOfIteratorHelperLoose(props), _step; !(_step = _iterator()).done; ) {
    var _step$value = _step.value, key = _step$value[0], val = _step$value[1];
    target[key] = val;
  }
  return target;
};

var _sfc_main = defineComponent({
  name: $prefix + "MonthTable",
  emits: ["changerange", "pick"],
  props: {
    date: {},
    defaultValue: {
      validator: function validator(val) {
        return val === null || isDate1(val) || Array.isArray(val) && val.every(isDate1);
      }
    },
    disabledDate: {
      type: Function,
      default: null
    },
    maxDate: {},
    minDate: {},
    rangeState: {
      default: function _default() {
        return {
          endDate: null,
          selecting: false
        };
      }
    },
    selectionMode: {
      default: "month"
    },
    readonly: {
      type: Boolean,
      default: false
    },
    value: {}
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var _hoisted_1 = ["textContent"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock(
    "table",
    {
      class: "tiny-month-table",
      onMousemove: _cache[0] || (_cache[0] = function() {
        return _ctx.handleMouseMove && _ctx.handleMouseMove.apply(_ctx, arguments);
      }),
      onClick: _cache[1] || (_cache[1] = function() {
        return _ctx.handleMonthTableClick && _ctx.handleMonthTableClick.apply(_ctx, arguments);
      })
    },
    [createElementVNode("tbody", null, [(openBlock(true), createElementBlock(
      Fragment,
      null,
      renderList(_ctx.state.rows, function(row, key) {
        return openBlock(), createElementBlock("tr", {
          key
        }, [(openBlock(true), createElementBlock(
          Fragment,
          null,
          renderList(row, function(cell, key2) {
            return openBlock(), createElementBlock(
              "td",
              {
                class: normalizeClass(_ctx.getCellStyle(cell)),
                key: key2
              },
              [createElementVNode("div", null, [createElementVNode("a", {
                class: "cell",
                textContent: toDisplayString(_ctx.t("ui.datepicker.months." + _ctx.state.months[cell.text]))
              }, null, 8, _hoisted_1)])],
              2
              /* CLASS */
            );
          }),
          128
          /* KEYED_FRAGMENT */
        ))]);
      }),
      128
      /* KEYED_FRAGMENT */
    ))])],
    32
    /* NEED_HYDRATION */
  );
}
var MonthTable = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
var version = "3.undefined";
MonthTable.install = function(Vue) {
  Vue.component(MonthTable.name, MonthTable);
};
MonthTable.version = version;

export { MonthTable as default };

==> vue-month-table-3.24.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/month-table/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { isDate1 } from '@opentinyvue/utils';
import { openBlock, createElementBlock, createElementVNode, Fragment, renderList, normalizeClass, toDisplayString } from 'vue';
import '@opentinyvue/vue-theme/month-table/index.css';

function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function() {
      return o >= r.length ? { done: true } : { done: false, value: r[o++] };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}
function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
var _export_sfc = function _export_sfc2(sfc, props) {
  var target = sfc.__vccOpts || sfc;
  for (var _iterator = _createForOfIteratorHelperLoose(props), _step; !(_step = _iterator()).done; ) {
    var _step$value = _step.value, key = _step$value[0], val = _step$value[1];
    target[key] = val;
  }
  return target;
};

var _sfc_main = defineComponent({
  name: $prefix + "MonthTable",
  emits: ["changerange", "pick"],
  props: {
    date: {},
    defaultValue: {
      validator: function validator(val) {
        return val === null || isDate1(val) || Array.isArray(val) && val.every(isDate1);
      }
    },
    disabledDate: {
      type: Function,
      default: null
    },
    maxDate: {},
    minDate: {},
    rangeState: {
      default: function _default() {
        return {
          endDate: null,
          selecting: false
        };
      }
    },
    selectionMode: {
      default: "month"
    },
    readonly: {
      type: Boolean,
      default: false
    },
    value: {}
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var _hoisted_1 = ["textContent"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock(
    "table",
    {
      class: "tiny-month-table",
      onMousemove: _cache[0] || (_cache[0] = function() {
        return _ctx.handleMouseMove && _ctx.handleMouseMove.apply(_ctx, arguments);
      }),
      onClick: _cache[1] || (_cache[1] = function() {
        return _ctx.handleMonthTableClick && _ctx.handleMonthTableClick.apply(_ctx, arguments);
      })
    },
    [createElementVNode("tbody", null, [(openBlock(true), createElementBlock(
      Fragment,
      null,
      renderList(_ctx.state.rows, function(row, key) {
        return openBlock(), createElementBlock("tr", {
          key
        }, [(openBlock(true), createElementBlock(
          Fragment,
          null,
          renderList(row, function(cell, key2) {
            return openBlock(), createElementBlock(
              "td",
              {
                class: normalizeClass(_ctx.getCellStyle(cell)),
                key: key2
              },
              [createElementVNode("div", null, [createElementVNode("a", {
                class: "cell",
                textContent: toDisplayString(_ctx.t("ui.datepicker.month" + (cell.text + 1)))
              }, null, 8, _hoisted_1)])],
              2
              /* CLASS */
            );
          }),
          128
          /* KEYED_FRAGMENT */
        ))]);
      }),
      128
      /* KEYED_FRAGMENT */
    ))])],
    32
    /* NEED_HYDRATION */
  );
}
var MonthTable = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
var version = "3.undefined";
MonthTable.install = function(Vue) {
  Vue.component(MonthTable.name, MonthTable);
};
MonthTable.version = version;

export { MonthTable as default };
